@@ -156,10 +156,9 @@ class Cleaner:
                     print "debug: process '%s' is running" % pathname
                     return True
             elif 'exe' == test and 'nt' == os.name:
-                for p in Windows.enumerate_processes():
-                    if p == pathname:
-                        print "debug: process '%s' is running" % pathname
-                        return True
+                if Windows.is_process_running(pathname):
+                    print "debug: process '%s' is running" % pathname
+                    return True
             elif 'pathname' == test:
                 expanded = os.path.expanduser(os.path.expandvars(pathname))
                 for globbed in glob.iglob(expanded):
@@ -373,7 +372,7 @@ class System(Cleaner):
             self.add_option('rotated_logs', _('Rotated logs'), _('Delete old system logs'))
             self.add_option('recent_documents', _('Recent documents list'), _('Delete the list of recently used documents'))
             self.add_option('trash', _('Trash'), _('Empty the trash'))
-        if 'linux2' == sys.platform:
+        if sys.platform.startswith('linux'):
             self.add_option('memory', _('Memory'), \
             # TRANSLATORS: 'free' means 'unallocated'
                _('Wipe the swap and free memory'))
@@ -411,6 +410,8 @@ class System(Cleaner):
         if 'posix' == os.name and 'cache' == option_id:
             dirname = os.path.expanduser("~/.cache/")
             for filename in children_in_directory(dirname, True):
+                if self.whitelisted(filename):
+                    continue
                 yield Command.Delete(filename)
 
         # menu
@@ -479,7 +480,7 @@ class System(Cleaner):
                     files += [ globbed ]
 
         # memory
-        if 'linux2' == sys.platform and 'memory' == option_id:
+        if sys.platform.startswith('linux') and 'memory' == option_id:
             yield Command.Function(None, Memory.wipe_memory, _('Memory'))
 
         # memory dump
@@ -495,8 +496,21 @@ class System(Cleaner):
         # most recently used documents list
         if 'posix' == os.name and 'recent_documents' == option_id:
             files += [ os.path.expanduser("~/.recently-used") ]
+            # GNOME 2.26 (as seen on Ubuntu 9.04) will retain the list
+            # in memory if it is simply deleted, so it must be shredded
+            # (or at least truncated).
+            #
+            # GNOME 2.28.1 (Ubuntu 9.10) and 2.30 (10.04) do not re-read
+            # the file after truncation, but do re-read it after
+            # shreading.
+            #
+            # https://bugzilla.gnome.org/show_bug.cgi?id=591404
+            for pathname in ["~/.recently-used.xbel", "~/.local/share/recently-used.xbel"]:
+                pathname = os.path.expanduser(pathname)
+                if os.path.lexists(pathname):
+                    yield Command.Shred(pathname)
+                    gtk.RecentManager().purge_items()
 
-        # fixme http://www.freedesktop.org/wiki/Specifications/desktop-bookmark-spec
 
         if 'posix' == os.name and 'rotated_logs' == option_id:
             for path in Unix.rotated_logs():
@@ -565,23 +579,6 @@ class System(Cleaner):
             yield Command.Function(None, clear_clipboard, _('Clipboard'))
 
 
-        # recent documents
-        if 'posix' == os.name and 'recent_documents' == option_id:
-            # GNOME 2.26 (as seen on Ubuntu 9.04) will retain the list
-            # in memory if it is simply deleted, so it must be shredded
-            # (or at least truncated).
-            #
-            # GNOME 2.28.1 (Ubuntu 9.10) and 2.30 (10.04) do not re-read
-            # the file after truncation, but do re-read it after
-            # shreading.
-            #
-            # https://bugzilla.gnome.org/show_bug.cgi?id=591404
-            pathname = os.path.expanduser("~/.recently-used.xbel")
-            if os.path.lexists(pathname):
-                yield Command.Shred(pathname)
-                gtk.RecentManager().purge_items()
-
-
         # overwrite free space
         shred_drives = options.get_list('shred_drives')
         if 'free_disk_space' == option_id and shred_drives:
@@ -641,6 +638,8 @@ class System(Cleaner):
             '^/tmp/orbit-[^/]+/bonobo-activation-server-[a-z0-9-]*ior$',
             '^/tmp/pulse-[^/]+/pid$',
             '^/var/tmp/kdecache-' ]
+        regexes.append('^'+os.path.expanduser('~/.cache/wallpaper/'))
+        regexes.append('^'+os.path.expanduser('~/.cache/gnome-control-center/'))
         for regex in regexes:
             if None != re.match(regex, pathname):
                 return True
