@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@ import os
 import types
 import FileUtilities
 
+from sqlite3 import DatabaseError
 from Common import _
 
 if 'nt' == os.name:
@@ -128,16 +129,24 @@ class Function:
                 if isinstance(func_ret, types.GeneratorType):
                     # function returned generator
                     for func_ret in self.func():
-                        if True == func_ret:
-                            # return control to GTK idle loop
-                            yield True
+                        if True == func_ret or isinstance(func_ret, tuple):
+                            # Return control to GTK idle loop.
+                            # If tuple, then display progress.
+                            yield func_ret
                 # either way, func_ret should be an integer
                 assert(isinstance(func_ret, (int, long)))
                 ret['size'] = func_ret
             else:
                 # Function takes a path.  We check the size.
                 oldsize = FileUtilities.getsize(self.path)
-                self.func(self.path)
+                try:
+                    self.func(self.path)
+                except DatabaseError, e:
+                    if -1 == e.message.find('file is encrypted or is not a database') and \
+                       -1 == e.message.find('or missing database'):
+                        raise
+                    print 'Warning:', e.message
+                    return
                 try:
                     newsize = FileUtilities.getsize(self.path)
                 except OSError, e:
@@ -151,6 +160,69 @@ class Function:
 
 
 
+class Ini:
+    """Remove sections or parameters from a .ini file"""
+
+    def __init__(self, path, section, parameter):
+        """Create the instance"""
+        self.path = path
+        self.section = section
+        self.parameter = parameter
+
+
+    def execute(self, really_delete):
+        """Make changes and return results"""
+
+        if FileUtilities.whitelisted(self.path):
+            yield whitelist(self.path)
+            return
+
+        ret = { \
+            # TRANSLATORS: Parts of this file will be deleted
+            'label' : _('Clean file'),
+            'n_deleted' : 0,
+            'n_special' : 1,
+            'path' : self.path,
+            'size' : None }
+        if really_delete:
+            oldsize = FileUtilities.getsize(self.path)
+            FileUtilities.clean_ini(self.path, self.section, self.parameter)
+            newsize = FileUtilities.getsize(self.path)
+            ret['size'] = oldsize - newsize
+        yield ret
+
+
+class Json:
+    """Remove a key from a JSON configuration file"""
+
+    def __init__(self, path, address):
+        """Create the instance"""
+        self.path = path
+        self.address = address
+
+
+    def execute(self, really_delete):
+        """Make changes and return results"""
+
+        if FileUtilities.whitelisted(self.path):
+            yield whitelist(self.path)
+            return
+
+        ret = { \
+            'label' : _('Clean file'),
+            'n_deleted' : 0,
+            'n_special' : 1,
+            'path' : self.path,
+            'size' : None }
+        if really_delete:
+            oldsize = FileUtilities.getsize(self.path)
+            FileUtilities.clean_json(self.path, self.address)
+            newsize = FileUtilities.getsize(self.path)
+            ret['size'] = oldsize - newsize
+        yield ret
+
+
+
 class Shred(Delete):
     """Shred a single file"""
 
