@@ -576,14 +576,16 @@ class GUI:
         cleaner_name = model[path[0]][0]
         # make a menu
         menu = gtk.Menu()
+        # TRANSLATORS: this is the context menu
         preview_item = gtk.MenuItem(_("Preview"))
         preview_item.connect('activate', self.cb_run_option, \
             False, cleaner_id, option_id)
         menu.append(preview_item)
-        delete_item = gtk.MenuItem(_("Delete"))
-        delete_item.connect('activate', self.cb_run_option, \
+        # TRANSLATORS: this is the context menu
+        clean_item = gtk.MenuItem(_("Clean"))
+        clean_item.connect('activate', self.cb_run_option, \
             True, cleaner_id, option_id)
-        menu.append(delete_item)
+        menu.append(clean_item)
 
         # show the context menu
         menu.attach_to_widget(treeview, menu.destroy)
@@ -673,12 +675,12 @@ class GUI:
         # create the delete button
         icon = gtk.Image()
         icon.set_from_stock(gtk.STOCK_DELETE, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        # TRANSLATORS: This is the delete button on the main window.
+        # TRANSLATORS: This is the clean button on the main window.
         # It makes permanent changes: usually deleting files, sometimes altering them.
-        run_button = gtk.ToolButton(icon_widget = icon, label = _p("button", "Delete"))
+        run_button = gtk.ToolButton(icon_widget = icon, label = _p("button", "Clean"))
         run_button.connect("clicked", self.run_operations)
         toolbar.insert(run_button, -1)
-        run_button.set_tooltip_text(_("Delete files in the selected operations"))
+        run_button.set_tooltip_text(_("Clean files in the selected operations"))
         run_button.set_is_important(True)
 
         return toolbar
@@ -767,8 +769,8 @@ class GUI:
             self.append_text(_("Error when checking for updates: ") + str(sys.exc_info()[1]), 'error')
 
 
-    def __init__(self):
-        if 'nt' == os.name and Windows.elevate_privileges():
+    def __init__(self, uac=True):
+        if uac and 'nt' == os.name and Windows.elevate_privileges():
             # privileges escalated in other process
             sys.exit(0)
         import RecognizeCleanerML
