@@ -29,6 +29,13 @@ from Options import options
 import FileUtilities
 
 
+def __get_chrome_history(path):
+    """Get Google Chrome or Chromium history version.  'path' is name of any file in same directory"""
+    path_history = os.path.join(os.path.dirname(path), 'History')
+    ver = get_sqlite_int(path_history, 'select value from meta where key="version"')[0]
+    assert(ver > 1)
+    return ver
+
 def __shred_sqlite_char_columns(table, cols = None, where = ""):
     """Create an SQL command to shred character columns"""
     cmd = ""
@@ -41,7 +48,7 @@ def __shred_sqlite_char_columns(table, cols = None, where = ""):
     return cmd
 
 
-def __get_sqlite_int(path, sql, parameters = None):
+def get_sqlite_int(path, sql, parameters = None):
     """Run SQL on database in 'path' and return the integers"""
     ids = []
     import sqlite3
@@ -78,11 +85,12 @@ def delete_chrome_favicons(path):
     """Delete Google Chrome and Chromium favicons not use in in history for bookmarks"""
 
     path_history = os.path.join(os.path.dirname(path), 'History')
-    ver = __get_sqlite_int(path, 'select value from meta where key="version"')[0]
+    ver = __get_chrome_history(path)
     cmds = ""
 
-    if 4 == ver:
+    if ver in [4, 20]:
         # Version 4 includes Chromium 12
+        # Version 20 includes Chromium 14, Google Chome 15
 
         # icon_mapping
         cols = ('page_url',)
@@ -123,6 +131,12 @@ def delete_chrome_history(path):
     cmds += __shred_sqlite_char_columns('visits')
     cols = ('lower_term', 'term')
     cmds += __shred_sqlite_char_columns('keyword_search_terms')
+    ver = __get_chrome_history(path)
+    if ver >= 20:
+        # downloads, segments, segment_usage first seen in Chrome 14, Google Chrome 15 (database version = 20)
+        cmds += __shred_sqlite_char_columns('downloads', ('full_path', 'url'))
+        cmds += __shred_sqlite_char_columns('segments', ('name',))
+        cmds += __shred_sqlite_char_columns('segment_usage')
     FileUtilities.execute_sqlite3(path, cmds)
 
 
@@ -199,7 +213,7 @@ def get_chrome_bookmark_ids(history_path):
     urls = get_chrome_bookmark_urls(bookmark_path)
     ids = []
     for url in urls:
-       ids +=  __get_sqlite_int(history_path, 'select id from urls where url=?', (url,))
+       ids +=  get_sqlite_int(history_path, 'select id from urls where url=?', (url,))
     return ids
 
 
