@@ -89,6 +89,7 @@ class Locales:
         'be' : 'Беларуская мова', \
         'bg' : 'български език', \
         'bn' : 'বাংলা', \
+        'bs' : 'босански', \
         'ca' : 'català', \
         'cs' : 'česky', \
         'da' : 'dansk', \
@@ -123,6 +124,7 @@ class Locales:
         'sr' : 'Српски', \
         'sv' : 'svenska', \
         'tr' : 'Türkçe', \
+        'ug' : 'Uyghur', \
         'uk' : 'Українська', \
         'vi' : 'Tiếng Việt', \
         'zh' : '中文' }
@@ -345,6 +347,7 @@ class Locales:
             return self.__native_locale_names[language_code]
         if os.path.exists('/usr/share/locale/all_languages'):
             if not self.__config_read:
+                # In Fedora 15, this file is provided by kdelibs-common
                 self.__config.read('/usr/share/locale/all_languages')
                 self.__config_read = True
             option = 'Name[%s]' % (language_code, )
