@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@ import tempfile
 import unittest
 
 sys.path.append('.')
-from bleachbit.DeepScan import DeepScan, ScanCache
+from bleachbit.DeepScan import DeepScan
 
 
 
@@ -99,19 +99,6 @@ class DeepScanTestCase(unittest.TestCase):
             self.assert_(os.path.lexists(ret))
 
 
-    def test_ScanCache(self):
-        """Unit test for class ScanCache"""
-        sc = ScanCache()
-        (fd, filename) = tempfile.mkstemp('bleachbit-deepscan-test')
-        os.close(fd)
-        self.assertEqual(sc.is_cached(filename), False)
-        sc.cache(filename)
-        self.assertEqual(sc.is_cached(filename), True)
-        os.remove(filename)
-        sc.purge()
-        self.assertEqual(sc.is_cached(filename), False)
-
-
 def suite():
     return unittest.makeSuite(DeepScanTestCase)
 
